.. _boundary_conditions_api:

===================
Boundary conditions
===================

.. currentmodule:: festim

.. autoclass:: DirichletBC
    :members:
    :show-inheritance:

.. autoclass:: CustomDirichlet
    :members:
    :show-inheritance:

.. autoclass:: ImplantationDirichlet
    :members:
    :show-inheritance:

.. autoclass:: HenrysBC
    :members:
    :show-inheritance:

.. autoclass:: SievertsBC
    :members:
    :show-inheritance:

.. autoclass:: FluxBC
    :members:
    :show-inheritance:

.. autoclass:: CustomFlux
    :members:
    :show-inheritance:

.. autoclass:: RecombinationFlux
    :members:
    :show-inheritance:

.. autoclass:: DissociationFlux
    :members:
    :show-inheritance:

.. autoclass:: ConvectiveFlux
    :members:
    :show-inheritance:

.. autoclass:: MassFlux
    :members:
    :show-inheritance:

.. autoclass:: SurfaceKinetics
    :members:
    :show-inheritance: